pype32.datadirs.Directory

Package pype32 :: Module datadirs :: Class Directory |
[hide private]
[frames] | no frames]

# Class Directory

source code

    object --+
             |
            Directory

Directory object.

Instance Methods | [hide private]
__init__(self, shouldPack=True) Class representation of the `IMAGE_DATA_DIRECTORY` structure. | source code
__str__(self) str(x) | source code
__len__(self) | source code
getType(self) Returns a value that identifies the Directory object. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods | [hide private]
Directory |
parse(readDataInstance) Returns a Directory-like object. | source code

Instance Variables | [hide private]
| rva DWORD rva.
| size DWORD size.
| info This variable holds the information of the directory.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, shouldPack=True) (Constructor) | source code
Class representation of the `IMAGE_DATA_DIRECTORY` structure. Parameters: `shouldPack` (bool) - If set to `True` the Directory object will be packed. If set to `False` the object won't be packed. Overrides: object.__init__ See Also: http://msdn.microsoft.com/es-es/library/windows/desktop/ms680305%28v=vs.85%29.aspx

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### parse(readDataInstance) Static Method | source code
Returns a Directory-like object. Parameters: `readDataInstance` (ReadData) - ReadData object to read from. Returns: Directory Directory object.